Public class
--------------------------

.. autoclass:: atx.drivers.Pattern
    :members:


Common methods
--------------------------

.. autoclass:: atx.drivers.mixin.DeviceMixin
    :members:


Method only for android
--------------------------

.. autoclass:: atx.drivers.android.AndroidDevice
    :members:

    .. attribute:: serial

        Android device serial number. **Optional**

Method only for windows
-----------------------
.. autoclass:: atx.drivers.windows.WindowsDevice
	:members: